/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface TeamsLocationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#account_id TeamsLocation#account_id}
    */
    readonly accountId: string;
    /**
    * Indicator that this is the default location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#client_default TeamsLocation#client_default}
    */
    readonly clientDefault?: boolean | cdktf.IResolvable;
    /**
    * IPv4 binding assigned to this location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#dns_destination_ips_id TeamsLocation#dns_destination_ips_id}
    */
    readonly dnsDestinationIpsId?: string;
    /**
    * IPv6 block binding assigned to this location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#dns_destination_ipv6_block_id TeamsLocation#dns_destination_ipv6_block_id}
    */
    readonly dnsDestinationIpv6BlockId?: string;
    /**
    * Indicator that this location needs to resolve EDNS queries.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#ecs_support TeamsLocation#ecs_support}
    */
    readonly ecsSupport?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#id TeamsLocation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the teams location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#name TeamsLocation#name}
    */
    readonly name: string;
    /**
    * The networks CIDRs that comprise the location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#networks TeamsLocation#networks}
    */
    readonly networks?: TeamsLocationNetworks[] | cdktf.IResolvable;
    /**
    * endpoints block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#endpoints TeamsLocation#endpoints}
    */
    readonly endpoints?: TeamsLocationEndpoints;
}
export interface TeamsLocationNetworks {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#network TeamsLocation#network}
    */
    readonly network?: string;
}
export declare function teamsLocationNetworksToTerraform(struct?: TeamsLocationNetworks | cdktf.IResolvable): any;
export declare function teamsLocationNetworksToHclTerraform(struct?: TeamsLocationNetworks | cdktf.IResolvable): any;
export declare class TeamsLocationNetworksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): TeamsLocationNetworks | cdktf.IResolvable | undefined;
    set internalValue(value: TeamsLocationNetworks | cdktf.IResolvable | undefined);
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
}
export declare class TeamsLocationNetworksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: TeamsLocationNetworks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): TeamsLocationNetworksOutputReference;
}
export interface TeamsLocationEndpointsDohNetworks {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#network TeamsLocation#network}
    */
    readonly network?: string;
}
export declare function teamsLocationEndpointsDohNetworksToTerraform(struct?: TeamsLocationEndpointsDohNetworks | cdktf.IResolvable): any;
export declare function teamsLocationEndpointsDohNetworksToHclTerraform(struct?: TeamsLocationEndpointsDohNetworks | cdktf.IResolvable): any;
export declare class TeamsLocationEndpointsDohNetworksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): TeamsLocationEndpointsDohNetworks | cdktf.IResolvable | undefined;
    set internalValue(value: TeamsLocationEndpointsDohNetworks | cdktf.IResolvable | undefined);
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
}
export declare class TeamsLocationEndpointsDohNetworksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: TeamsLocationEndpointsDohNetworks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): TeamsLocationEndpointsDohNetworksOutputReference;
}
export interface TeamsLocationEndpointsDoh {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#enabled TeamsLocation#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#networks TeamsLocation#networks}
    */
    readonly networks?: TeamsLocationEndpointsDohNetworks[] | cdktf.IResolvable;
}
export declare function teamsLocationEndpointsDohToTerraform(struct?: TeamsLocationEndpointsDohOutputReference | TeamsLocationEndpointsDoh): any;
export declare function teamsLocationEndpointsDohToHclTerraform(struct?: TeamsLocationEndpointsDohOutputReference | TeamsLocationEndpointsDoh): any;
export declare class TeamsLocationEndpointsDohOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): TeamsLocationEndpointsDoh | undefined;
    set internalValue(value: TeamsLocationEndpointsDoh | undefined);
    get authenticationEnabled(): cdktf.IResolvable;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _networks;
    get networks(): TeamsLocationEndpointsDohNetworksList;
    putNetworks(value: TeamsLocationEndpointsDohNetworks[] | cdktf.IResolvable): void;
    resetNetworks(): void;
    get networksInput(): cdktf.IResolvable | TeamsLocationEndpointsDohNetworks[] | undefined;
    get requireToken(): cdktf.IResolvable;
}
export interface TeamsLocationEndpointsDotNetworks {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#network TeamsLocation#network}
    */
    readonly network?: string;
}
export declare function teamsLocationEndpointsDotNetworksToTerraform(struct?: TeamsLocationEndpointsDotNetworks | cdktf.IResolvable): any;
export declare function teamsLocationEndpointsDotNetworksToHclTerraform(struct?: TeamsLocationEndpointsDotNetworks | cdktf.IResolvable): any;
export declare class TeamsLocationEndpointsDotNetworksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): TeamsLocationEndpointsDotNetworks | cdktf.IResolvable | undefined;
    set internalValue(value: TeamsLocationEndpointsDotNetworks | cdktf.IResolvable | undefined);
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
}
export declare class TeamsLocationEndpointsDotNetworksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: TeamsLocationEndpointsDotNetworks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): TeamsLocationEndpointsDotNetworksOutputReference;
}
export interface TeamsLocationEndpointsDot {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#enabled TeamsLocation#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#networks TeamsLocation#networks}
    */
    readonly networks?: TeamsLocationEndpointsDotNetworks[] | cdktf.IResolvable;
}
export declare function teamsLocationEndpointsDotToTerraform(struct?: TeamsLocationEndpointsDotOutputReference | TeamsLocationEndpointsDot): any;
export declare function teamsLocationEndpointsDotToHclTerraform(struct?: TeamsLocationEndpointsDotOutputReference | TeamsLocationEndpointsDot): any;
export declare class TeamsLocationEndpointsDotOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): TeamsLocationEndpointsDot | undefined;
    set internalValue(value: TeamsLocationEndpointsDot | undefined);
    get authenticationEnabled(): cdktf.IResolvable;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _networks;
    get networks(): TeamsLocationEndpointsDotNetworksList;
    putNetworks(value: TeamsLocationEndpointsDotNetworks[] | cdktf.IResolvable): void;
    resetNetworks(): void;
    get networksInput(): cdktf.IResolvable | TeamsLocationEndpointsDotNetworks[] | undefined;
    get requireToken(): cdktf.IResolvable;
}
export interface TeamsLocationEndpointsIpv4 {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#enabled TeamsLocation#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function teamsLocationEndpointsIpv4ToTerraform(struct?: TeamsLocationEndpointsIpv4OutputReference | TeamsLocationEndpointsIpv4): any;
export declare function teamsLocationEndpointsIpv4ToHclTerraform(struct?: TeamsLocationEndpointsIpv4OutputReference | TeamsLocationEndpointsIpv4): any;
export declare class TeamsLocationEndpointsIpv4OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): TeamsLocationEndpointsIpv4 | undefined;
    set internalValue(value: TeamsLocationEndpointsIpv4 | undefined);
    get authenticationEnabled(): cdktf.IResolvable;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface TeamsLocationEndpointsIpv6Networks {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#network TeamsLocation#network}
    */
    readonly network?: string;
}
export declare function teamsLocationEndpointsIpv6NetworksToTerraform(struct?: TeamsLocationEndpointsIpv6Networks | cdktf.IResolvable): any;
export declare function teamsLocationEndpointsIpv6NetworksToHclTerraform(struct?: TeamsLocationEndpointsIpv6Networks | cdktf.IResolvable): any;
export declare class TeamsLocationEndpointsIpv6NetworksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): TeamsLocationEndpointsIpv6Networks | cdktf.IResolvable | undefined;
    set internalValue(value: TeamsLocationEndpointsIpv6Networks | cdktf.IResolvable | undefined);
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
}
export declare class TeamsLocationEndpointsIpv6NetworksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: TeamsLocationEndpointsIpv6Networks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): TeamsLocationEndpointsIpv6NetworksOutputReference;
}
export interface TeamsLocationEndpointsIpv6 {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#enabled TeamsLocation#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#networks TeamsLocation#networks}
    */
    readonly networks?: TeamsLocationEndpointsIpv6Networks[] | cdktf.IResolvable;
}
export declare function teamsLocationEndpointsIpv6ToTerraform(struct?: TeamsLocationEndpointsIpv6OutputReference | TeamsLocationEndpointsIpv6): any;
export declare function teamsLocationEndpointsIpv6ToHclTerraform(struct?: TeamsLocationEndpointsIpv6OutputReference | TeamsLocationEndpointsIpv6): any;
export declare class TeamsLocationEndpointsIpv6OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): TeamsLocationEndpointsIpv6 | undefined;
    set internalValue(value: TeamsLocationEndpointsIpv6 | undefined);
    get authenticationEnabled(): cdktf.IResolvable;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _networks;
    get networks(): TeamsLocationEndpointsIpv6NetworksList;
    putNetworks(value: TeamsLocationEndpointsIpv6Networks[] | cdktf.IResolvable): void;
    resetNetworks(): void;
    get networksInput(): cdktf.IResolvable | TeamsLocationEndpointsIpv6Networks[] | undefined;
}
export interface TeamsLocationEndpoints {
    /**
    * doh block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#doh TeamsLocation#doh}
    */
    readonly doh?: TeamsLocationEndpointsDoh;
    /**
    * dot block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#dot TeamsLocation#dot}
    */
    readonly dot?: TeamsLocationEndpointsDot;
    /**
    * ipv4 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#ipv4 TeamsLocation#ipv4}
    */
    readonly ipv4?: TeamsLocationEndpointsIpv4;
    /**
    * ipv6 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#ipv6 TeamsLocation#ipv6}
    */
    readonly ipv6?: TeamsLocationEndpointsIpv6;
}
export declare function teamsLocationEndpointsToTerraform(struct?: TeamsLocationEndpointsOutputReference | TeamsLocationEndpoints): any;
export declare function teamsLocationEndpointsToHclTerraform(struct?: TeamsLocationEndpointsOutputReference | TeamsLocationEndpoints): any;
export declare class TeamsLocationEndpointsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): TeamsLocationEndpoints | undefined;
    set internalValue(value: TeamsLocationEndpoints | undefined);
    private _doh;
    get doh(): TeamsLocationEndpointsDohOutputReference;
    putDoh(value: TeamsLocationEndpointsDoh): void;
    resetDoh(): void;
    get dohInput(): TeamsLocationEndpointsDoh | undefined;
    private _dot;
    get dot(): TeamsLocationEndpointsDotOutputReference;
    putDot(value: TeamsLocationEndpointsDot): void;
    resetDot(): void;
    get dotInput(): TeamsLocationEndpointsDot | undefined;
    private _ipv4;
    get ipv4(): TeamsLocationEndpointsIpv4OutputReference;
    putIpv4(value: TeamsLocationEndpointsIpv4): void;
    resetIpv4(): void;
    get ipv4Input(): TeamsLocationEndpointsIpv4 | undefined;
    private _ipv6;
    get ipv6(): TeamsLocationEndpointsIpv6OutputReference;
    putIpv6(value: TeamsLocationEndpointsIpv6): void;
    resetIpv6(): void;
    get ipv6Input(): TeamsLocationEndpointsIpv6 | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location cloudflare_teams_location}
*/
export declare class TeamsLocation extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_teams_location";
    /**
    * Generates CDKTF code for importing a TeamsLocation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the TeamsLocation to import
    * @param importFromId The id of the existing TeamsLocation that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the TeamsLocation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.52.0/docs/resources/teams_location cloudflare_teams_location} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options TeamsLocationConfig
    */
    constructor(scope: Construct, id: string, config: TeamsLocationConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get anonymizedLogsEnabled(): cdktf.IResolvable;
    private _clientDefault?;
    get clientDefault(): boolean | cdktf.IResolvable;
    set clientDefault(value: boolean | cdktf.IResolvable);
    resetClientDefault(): void;
    get clientDefaultInput(): boolean | cdktf.IResolvable | undefined;
    private _dnsDestinationIpsId?;
    get dnsDestinationIpsId(): string;
    set dnsDestinationIpsId(value: string);
    resetDnsDestinationIpsId(): void;
    get dnsDestinationIpsIdInput(): string | undefined;
    private _dnsDestinationIpv6BlockId?;
    get dnsDestinationIpv6BlockId(): string;
    set dnsDestinationIpv6BlockId(value: string);
    resetDnsDestinationIpv6BlockId(): void;
    get dnsDestinationIpv6BlockIdInput(): string | undefined;
    get dohSubdomain(): string;
    private _ecsSupport?;
    get ecsSupport(): boolean | cdktf.IResolvable;
    set ecsSupport(value: boolean | cdktf.IResolvable);
    resetEcsSupport(): void;
    get ecsSupportInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get ip(): string;
    get ipv4Destination(): string;
    get ipv4DestinationBackup(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networks;
    get networks(): TeamsLocationNetworksList;
    putNetworks(value: TeamsLocationNetworks[] | cdktf.IResolvable): void;
    resetNetworks(): void;
    get networksInput(): cdktf.IResolvable | TeamsLocationNetworks[] | undefined;
    private _endpoints;
    get endpoints(): TeamsLocationEndpointsOutputReference;
    putEndpoints(value: TeamsLocationEndpoints): void;
    resetEndpoints(): void;
    get endpointsInput(): TeamsLocationEndpoints | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
